@@ -1,6 +1,6 @@
 # Copyright 2010,2014 Bank Of Italy
 #
-# Licensed under the EUPL, Version 1.1 or  as soon they
+# Licensed under the EUPL, Version 1.1 or - as soon they
 # will be approved by the European Commission - subsequent
 # versions of the EUPL (the "Licence");
 # You may not use this work except in compliance with the
@@ -38,8 +38,8 @@ getDSDIdentifier <- function(provider, dataflow) {
 }
 
 # add a new sdmx provider
-addProvider <- function(name, agency, endpoint, needsCredentials=F) {  	
-  J("it.bankitalia.reri.sia.sdmx.client.SdmxClientHandler")$addProvider(name, agency, endpoint, needsCredentials)
+addProvider <- function(name, endpoint, needsCredentials=F) {  	
+  J("it.bankitalia.reri.sia.sdmx.client.SdmxClientHandler")$addProvider(name, endpoint, needsCredentials)
 }
 
 # get dimensions of the given dataflow (after retrieving the key family)
